@@ -132,7 +132,7 @@ sub cmpSystems($$$)
         {
             my ($Soname, $V) = ($LibSoname1{$Name}, $LibV1{$Name});
             if(not $V) {
-                $V = parse_libname($Name, "version");
+                $V = parse_libname($Name, "version", $OStarget);
             }
             if($GroupByHeaders) {
                 $Soname = $Name;
@@ -146,7 +146,7 @@ sub cmpSystems($$$)
         {
             my ($Soname, $V) = ($LibSoname2{$Name}, $LibV2{$Name});
             if(not $V) {
-                $V = parse_libname($Name, "version");
+                $V = parse_libname($Name, "version", $OStarget);
             }
             if($GroupByHeaders) {
                 $Soname = $Name;
@@ -209,7 +209,7 @@ sub cmpSystems($$$)
             { # removed library
                 if(not $LibSoname2{$LName})
                 {
-                    $RemovedShort{parse_libname($LName, "name+ext")}{$LName}=1;
+                    $RemovedShort{parse_libname($LName, "name+ext", $OStarget)}{$LName}=1;
                     $Removed{$LName}{"version"}=$Versions1[0];
                     my $ListPath = "info/$LName/symbols.html";
                     createSymbolsList($LibVers1{$LName}{$Versions1[0]},
@@ -240,7 +240,7 @@ sub cmpSystems($$$)
             { # added library
                 if(not $LibSoname1{$LName})
                 {
-                    $AddedShort{parse_libname($LName, "name+ext")}{$LName}=1;
+                    $AddedShort{parse_libname($LName, "name+ext", $OStarget)}{$LName}=1;
                     $Added{$LName}{"version"}=$Versions2[0];
                     my $ListPath = "info/$LName/symbols.html";
                     createSymbolsList($LibVers2{$LName}{$Versions2[0]},
@@ -290,7 +290,7 @@ sub cmpSystems($$$)
             }
             $LV2 = $Versions2[0];
             $DPath2 = $LibVers2{$LName2}{$LV2};
-            $LName = parse_libname($LName, "name+ext");
+            $LName = parse_libname($LName, "name+ext", $OStarget);
             $SONAME_Changed{$LName} = 1;
         }
         else
@@ -389,7 +389,7 @@ sub cmpSystems($$$)
             $SYS_REPORT .= "<td>".$TestResults{$LName}{"v1"}."</td>\n";
         }
         if(defined $Added{$LName})
-        {# added library
+        { # added library
             $SYS_REPORT .= "<td class='new'>".$Added{$LName}{"version"}."</td>\n";
             $SYS_REPORT .= "<td class='passed'>100%</td>\n";
             if($RegisteredPairs{$LName}) {
@@ -398,7 +398,7 @@ sub cmpSystems($$$)
             elsif(my $To = $ChangedSoname{$LName})
             {
                 $RegisteredPairs{$To}=1;
-                $SYS_REPORT .= "<td colspan='5' rowspan='2'>SONAME has <a href='".$TestResults{parse_libname($LName, "name+ext")}{"path"}."'>changed</a></td>\n";
+                $SYS_REPORT .= "<td colspan='5' rowspan='2'>SONAME has <a href='".$TestResults{parse_libname($LName, "name+ext", $OStarget)}{"path"}."'>changed</a></td>\n";
             }
             else {
                 foreach (1 .. 5) {
@@ -409,7 +409,7 @@ sub cmpSystems($$$)
             next;
         }
         elsif(defined $Removed{$LName})
-        {# removed library
+        { # removed library
             $SYS_REPORT .= "<td class='failed'><a href='".$Removed{$LName}{"list"}."'>removed</a></td>\n";
             $SYS_REPORT .= "<td class='failed'>0%</td>\n";
             if($RegisteredPairs{$LName}) {
@@ -418,7 +418,7 @@ sub cmpSystems($$$)
             elsif(my $To = $ChangedSoname{$LName})
             {
                 $RegisteredPairs{$To}=1;
-                $SYS_REPORT .= "<td colspan='5' rowspan='2'>SONAME has <a href='".$TestResults{parse_libname($LName, "name+ext")}{"path"}."'>changed</a></td>\n";
+                $SYS_REPORT .= "<td colspan='5' rowspan='2'>SONAME has <a href='".$TestResults{parse_libname($LName, "name+ext", $OStarget)}{"path"}."'>changed</a></td>\n";
             }
             else {
                 foreach (1 .. 5) {
@@ -491,6 +491,60 @@ sub cmpSystems($$$)
         }
         $SYS_REPORT .= "</tr>\n";
     }
+    my @META_DATA = ();
+    my %Stat = (
+        "total"=>int(keys(%TestResults)),
+        "added"=>int(keys(%Added)),
+        "removed"=>int(keys(%Removed))
+    );
+    foreach ("added", "removed")
+    {
+        my $Kind = $_."_interfaces";
+        foreach my $LName (keys(%TestResults)) {
+            $Stat{$Kind} += $TestResults{$LName}{$_};
+        }
+        push(@META_DATA, $Kind.":".$Stat{$Kind});
+    }
+    foreach my $T ("type", "interface")
+    {
+        foreach my $S ("high", "medium", "low")
+        {
+            my $Kind = $T."_problems_".$S;
+            foreach my $LName (keys(%TestResults)) {
+                $Stat{$Kind} += $TestResults{$LName}{$Kind};
+            }
+            push(@META_DATA, $Kind.":".$Stat{$Kind});
+        }
+    }
+    foreach my $LName (keys(%TestResults))
+    {
+        foreach ("affected", "changed_constants") {
+            $Stat{$_} += $TestResults{$LName}{$_};
+        }
+        if(not defined $Stat{"verdict"}
+        and $TestResults{$LName}{"verdict"} eq "incompatible") {
+            $Stat{"verdict"} = "incompatible";
+        }
+    }
+    if(not defined $Stat{"verdict"}) {
+        $Stat{"verdict"} = "compatible";
+    }
+    if($Stat{"total"}) {
+        $Stat{"affected"} /= $Stat{"total"};
+    }
+    else {
+        $Stat{"affected"} = 0;
+    }
+    $Stat{"affected"} = show_number($Stat{"affected"});
+    if($Stat{"verdict"}>1) {
+        $Stat{"verdict"} = 1;
+    }
+    push(@META_DATA, "changed_constants:".$Stat{"changed_constants"});
+    push(@META_DATA, "tool_version:".get_dumpversion("perl $0"));
+    foreach ("removed", "added", "total", "affected", "verdict") {
+        @META_DATA = ($_.":".$Stat{$_}, @META_DATA);
+    }
+    
     # bottom header
     $SYS_REPORT .= "<tr><th rowspan='2'>$SONAME_Title</th>";
     if(not $GroupByHeaders) {
@@ -509,7 +563,7 @@ sub cmpSystems($$$)
     my $Keywords = "compatibility, $SystemName1, $SystemName2, API, changes";
     my $Description = "Binary compatibility between $SystemName1 and $SystemName2 on ".showArch($ArchName);
     my $Styles = readStyles("CmpSystems.css");
-    writeFile($SYS_REPORT_PATH."/abi_compat_report.html", composeHTML_Head($Title, $Keywords, $Description, $Styles)."\n<body>
+    writeFile($SYS_REPORT_PATH."/abi_compat_report.html", "<!-\- ".join(";", @META_DATA)." -\->\n".composeHTML_Head($Title, $Keywords, $Description, $Styles)."\n<body>
     <div>$SYS_REPORT</div>
     <br/><br/><br/><hr/>
     ".getReportFooter($SystemName2)."
@@ -956,7 +1010,7 @@ sub dumpSystem($)
         { # binary version
             $SysLibVersion{$LName} = $V;
         }
-        elsif(my $V = parse_libname($LName, "version"))
+        elsif(my $V = parse_libname($LName, "version", $OStarget))
         { # source version
             $SysLibVersion{$LName} = $V;
         }
@@ -978,7 +1032,7 @@ sub dumpSystem($)
     foreach my $LPath (sort @SystemLibs)
     {
         my $LName = get_filename($LPath);
-        my $LSName = parse_libname($LName, "short");
+        my $LSName = parse_libname($LName, "short", $OStarget);
         my $LRelPath = cut_path_prefix($LPath, $SystemRoot);
         if(not is_target_lib($LName)) {
             next;
@@ -989,11 +1043,11 @@ sub dumpSystem($)
         }
         if($OStarget eq "symbian")
         {
-            if(my $V = parse_libname($LName, "version"))
+            if(my $V = parse_libname($LName, "version", $OStarget))
             { # skip qtcore.dso
               # register qtcore{00040604}.dso
                 delete($SysLibs{get_dirname($LPath)."\\".$LSName.".".$LIB_EXT});
-                my $MV = parse_libname($LibSoname{$LSName.".".$LIB_EXT}, "version");
+                my $MV = parse_libname($LibSoname{$LSName.".".$LIB_EXT}, "version", $OStarget);
                 if($MV and $V ne $MV)
                 { # skip other versions:
                   #  qtcore{00040700}.dso
@@ -1114,11 +1168,11 @@ sub dumpSystem($)
     foreach my $LPath1 (sort keys(%SysLib_Symbols))
     { # match duplicated libs
       # libmenu contains all symbols from libmenuw
-        my $SName = parse_libname(get_filename($LPath1), "shortest");
+        my $SName = parse_libname(get_filename($LPath1), "shortest", $OStarget);
         foreach my $LPath2 (sort keys(%SysLib_Symbols))
         {
             next if($LPath1 eq $LPath2);
-            if($SName eq parse_libname(get_filename($LPath2), "shortest"))
+            if($SName eq parse_libname(get_filename($LPath2), "shortest", $OStarget))
             { # libpython-X.Y
                 $VersionedLibs{$LPath1}{$LPath2}=1;
                 next;
@@ -1221,10 +1275,10 @@ sub dumpSystem($)
     foreach my $LPath (sort keys(%SysLibs))
     { # matching
         my $LName = get_filename($LPath);
-        my $LNameSE = parse_libname($LName, "name+ext");
+        my $LNameSE = parse_libname($LName, "name+ext", $OStarget);
         my $LRelPath = cut_path_prefix($LPath, $SystemRoot);
-        my $LSName = parse_libname($LName, "short");
-        my $SName = parse_libname($LName, "shortest");
+        my $LSName = parse_libname($LName, "short", $OStarget);
+        my $SName = parse_libname($LName, "shortest", $OStarget);
         if($LRelPath=~/\/debug\//)
         { # debug libs
             $Skipped{$LRelPath}=1;
@@ -1405,7 +1459,7 @@ sub dumpSystem($)
         unlink($DPath);
         if(my @LibHeaders = keys(%{$SysLib_SysHeaders{$LRelPath}}))
         {
-            my $LSName = parse_libname($LName, "short");
+            my $LSName = parse_libname($LName, "short", $OStarget);
             if($GroupByHeaders)
             { # header short name
                 $LSName = $LName;
@@ -1462,7 +1516,7 @@ sub dumpSystem($)
             }
             my @Content = ("<version>\n    $LVersion\n</version>");
             my @IncHeaders = sort {natural_sorting($a, $b)} keys(%Includes);
-            sort_by_word(\@IncHeaders, parse_libname($LName, "shortest"));
+            sort_by_word(\@IncHeaders, parse_libname($LName, "shortest", $OStarget));
             if(is_abs($IncHeaders[0])) {
                 push(@Content, "<headers>\n    ".join("\n    ", @IncHeaders)."\n</headers>");
             }
@@ -1593,7 +1647,7 @@ sub dumpSystem($)
             $ACC_dump .= " -l $LName";
         }
         else {
-            $ACC_dump .= " -l ".parse_libname($LName, "name");
+            $ACC_dump .= " -l ".parse_libname($LName, "name", $OStarget);
         }
         $ACC_dump .= " -dump \"$DPath\"";
         if($SystemRoot)
